@@ -1,6 +1,6 @@
 use bytes::{buf::Reader, Buf};
-use hyper::{Body, Client, Method, Request, StatusCode};
-use std::io::Read;
+use hyper::{body, Body, Client, Method, Request, StatusCode};
+use std::{collections::HashMap, io::Read};
 
 use crate::types;
 
@@ -54,3 +54,34 @@ pub async fn get(url: &String) -> types::Result<(StatusCode, serde_json::Value)>
     let result: serde_json::Value = serde_json::from_reader(reader)?;
     Ok((status, result))
 }
+
+pub async fn post_with_headers(
+    url: &String,
+    headers: &HashMap<String, String>,
+    body: hyper::Body,
+) -> types::Result<(StatusCode, Reader<impl Buf>)> {
+    let mut builder = Request::builder().method(Method::POST).uri(url);
+    //.header("Accept", "application/json");
+
+    for (k, v) in headers {
+        builder = builder.header(k, v);
+    }
+
+    let req_result = builder.body(body);
+
+    if req_result.is_err() {
+        println!("{:?}", req_result);
+        panic!("Can`t connect");
+    }
+
+    let req = req_result.unwrap();
+
+    let client = Client::new();
+    let res = client.request(req).await?;
+    let status = res.status();
+
+    let body = hyper::body::aggregate(res).await?;
+    let reader = body.reader();
+
+    Ok((status, reader))
+}
